# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = [
    'api_url',
    'auth_token',
    'custom_app_url',
    'timeout_seconds',
]

__config__ = pulumi.Config('signalfx')

api_url = __config__.get('apiUrl')
"""
API URL for your SignalFx org, may include a realm
"""

auth_token = __config__.get('authToken') or _utilities.get_env('SFX_AUTH_TOKEN')
"""
SignalFx auth token
"""

custom_app_url = __config__.get('customAppUrl')
"""
Application URL for your SignalFx org, often customzied for organizations using SSO
"""

timeout_seconds = __config__.get('timeoutSeconds')
"""
Timeout duration for a single HTTP call in seconds. Defaults to 120
"""

